mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: Serge Semin <fancer.lancer@gmail.com>
To: jdmason@kudzu.us, dave.jiang@intel.com, Allen.Hubbe@emc.com,
	Shyam-sundar.S-k@amd.com, Xiangliang.Yu@amd.com,
	gary.hook@amd.com
Cc: Sergey.Semin@t-platforms.ru, linux-ntb@googlegroups.com,
	linux-kernel@vger.kernel.org,
	Serge Semin <fancer.lancer@gmail.com>
Subject: [PATCH v4 01/15] NTB: Rename NTB messaging API methods
Date: Wed,  6 Dec 2017 17:31:52 +0300	[thread overview]
Message-ID: <20171206143206.14665-2-fancer.lancer@gmail.com> (raw)
In-Reply-To: <20171206143206.14665-1-fancer.lancer@gmail.com>

There is a common methods signature form used over all the NTB API
like functions naming scheme, arguments names and order, etc.
Recently added NTB messaging API IO callbacks were named a bit
different so should be renamed to be in compliance with the rest
of the API.

Signed-off-by: Serge Semin <fancer.lancer@gmail.com>
---
 drivers/ntb/hw/idt/ntb_hw_idt.c | 27 ++++++++++++---------------
 include/linux/ntb.h             | 34 ++++++++++++++++------------------
 2 files changed, 28 insertions(+), 33 deletions(-)

diff --git a/drivers/ntb/hw/idt/ntb_hw_idt.c b/drivers/ntb/hw/idt/ntb_hw_idt.c
index 0cd79f367f7c..24040317bb9c 100644
--- a/drivers/ntb/hw/idt/ntb_hw_idt.c
+++ b/drivers/ntb/hw/idt/ntb_hw_idt.c
@@ -1744,20 +1744,19 @@ static int idt_ntb_msg_clear_mask(struct ntb_dev *ntb, u64 mask_bits)
  * idt_ntb_msg_read() - read message register with specified index
  *			(NTB API callback)
  * @ntb:	NTB device context.
- * @midx:	Message register index
  * @pidx:	OUT - Port index of peer device a message retrieved from
- * @msg:	OUT - Data
+ * @midx:	Message register index
  *
  * Read data from the specified message register and source register.
  *
- * Return: zero on success, negative error if invalid argument passed.
+ * Return: inbound message register value.
  */
-static int idt_ntb_msg_read(struct ntb_dev *ntb, int midx, int *pidx, u32 *msg)
+static u32 idt_ntb_msg_read(struct ntb_dev *ntb, int *pidx, int midx)
 {
 	struct idt_ntb_dev *ndev = to_ndev_ntb(ntb);
 
 	if (midx < 0 || IDT_MSG_CNT <= midx)
-		return -EINVAL;
+		return ~(u32)0;
 
 	/* Retrieve source port index of the message */
 	if (pidx != NULL) {
@@ -1772,18 +1771,15 @@ static int idt_ntb_msg_read(struct ntb_dev *ntb, int midx, int *pidx, u32 *msg)
 	}
 
 	/* Retrieve data of the corresponding message register */
-	if (msg != NULL)
-		*msg = idt_nt_read(ndev, ntdata_tbl.msgs[midx].in);
-
-	return 0;
+	return idt_nt_read(ndev, ntdata_tbl.msgs[midx].in);
 }
 
 /*
  * idt_ntb_msg_write() - write data to the specified message register
  *			 (NTB API callback)
  * @ntb:	NTB device context.
- * @midx:	Message register index
  * @pidx:	Port index of peer device a message being sent to
+ * @midx:	Message register index
  * @msg:	Data to send
  *
  * Just try to send data to a peer. Message status register should be
@@ -1791,7 +1787,8 @@ static int idt_ntb_msg_read(struct ntb_dev *ntb, int midx, int *pidx, u32 *msg)
  *
  * Return: zero on success, negative error if invalid argument passed.
  */
-static int idt_ntb_msg_write(struct ntb_dev *ntb, int midx, int pidx, u32 msg)
+static int idt_ntb_peer_msg_write(struct ntb_dev *ntb, int pidx, int midx,
+				  u32 msg)
 {
 	struct idt_ntb_dev *ndev = to_ndev_ntb(ntb);
 	unsigned long irqflags;
@@ -2058,7 +2055,7 @@ static const struct ntb_dev_ops idt_ntb_ops = {
 	.msg_set_mask		= idt_ntb_msg_set_mask,
 	.msg_clear_mask		= idt_ntb_msg_clear_mask,
 	.msg_read		= idt_ntb_msg_read,
-	.msg_write		= idt_ntb_msg_write
+	.peer_msg_write		= idt_ntb_peer_msg_write
 };
 
 /*
@@ -2269,7 +2266,7 @@ static ssize_t idt_dbgfs_info_read(struct file *filp, char __user *ubuf,
 		 "Message data:\n");
 	for (idx = 0; idx < IDT_MSG_CNT; idx++) {
 		int src;
-		(void)idt_ntb_msg_read(&ndev->ntb, idx, &src, &data);
+		data = idt_ntb_msg_read(&ndev->ntb, &src, idx);
 		off += scnprintf(strbuf + off, size - off,
 			"\t%hhu. 0x%08x from peer %hhu (Port %hhu)\n",
 			idx, data, src, ndev->peers[src].port);
@@ -1772,18 +1771,15 @@ static int idt_ntb_msg_read(struct ntb_dev *ntb, int midx, int *pidx, u32 *msg)
 
 /*
- * idt_ntb_msg_write() - write data to the specified message register
- *			 (NTB API callback)
+ * idt_ntb_peer_msg_write() - write data to the specified message register
+ *			      (NTB API callback)
  * @ntb:	NTB device context.
diff --git a/include/linux/ntb.h b/include/linux/ntb.h
index ea3be7275a5e..21b1826a0953 100644
--- a/include/linux/ntb.h
+++ b/include/linux/ntb.h
@@ -253,7 +253,7 @@ static inline int ntb_ctx_ops_is_valid(const struct ntb_ctx_ops *ops)
  * @msg_set_mask:	See ntb_msg_set_mask().
  * @msg_clear_mask:	See ntb_msg_clear_mask().
  * @msg_read:		See ntb_msg_read().
- * @msg_write:		See ntb_msg_write().
+ * @peer_msg_write:	See ntb_peer_msg_write().
  */
 struct ntb_dev_ops {
 	int (*port_number)(struct ntb_dev *ntb);
@@ -324,8 +324,8 @@ struct ntb_dev_ops {
 	int (*msg_clear_sts)(struct ntb_dev *ntb, u64 sts_bits);
 	int (*msg_set_mask)(struct ntb_dev *ntb, u64 mask_bits);
 	int (*msg_clear_mask)(struct ntb_dev *ntb, u64 mask_bits);
-	int (*msg_read)(struct ntb_dev *ntb, int midx, int *pidx, u32 *msg);
-	int (*msg_write)(struct ntb_dev *ntb, int midx, int pidx, u32 msg);
+	u32 (*msg_read)(struct ntb_dev *ntb, int *pidx, int midx);
+	int (*peer_msg_write)(struct ntb_dev *ntb, int pidx, int midx, u32 msg);
 };
 
 static inline int ntb_dev_ops_is_valid(const struct ntb_dev_ops *ops)
@@ -387,7 +387,7 @@ static inline int ntb_dev_ops_is_valid(const struct ntb_dev_ops *ops)
 		/* !ops->msg_set_mask == !ops->msg_count	&& */
 		/* !ops->msg_clear_mask == !ops->msg_count	&& */
 		!ops->msg_read == !ops->msg_count		&&
-		!ops->msg_write == !ops->msg_count		&&
+		!ops->peer_msg_write == !ops->msg_count		&&
 		1;
 }
 
@@ -1462,31 +1462,29 @@ static inline int ntb_msg_clear_mask(struct ntb_dev *ntb, u64 mask_bits)
 }
 
 /**
- * ntb_msg_read() - read message register with specified index
+ * ntb_msg_read() - read inbound message register with specified index
  * @ntb:	NTB device context.
- * @midx:	Message register index
  * @pidx:	OUT - Port index of peer device a message retrieved from
- * @msg:	OUT - Data
+ * @midx:	Message register index
  *
  * Read data from the specified message register. Source port index of a
  * message is retrieved as well.
  *
- * Return: Zero on success, otherwise a negative error number.
+ * Return: The value of the inbound message register.
  */
-static inline int ntb_msg_read(struct ntb_dev *ntb, int midx, int *pidx,
-			       u32 *msg)
+static inline u32 ntb_msg_read(struct ntb_dev *ntb, int *pidx, int midx)
 {
 	if (!ntb->ops->msg_read)
-		return -EINVAL;
+		return ~(u32)0;
 
-	return ntb->ops->msg_read(ntb, midx, pidx, msg);
+	return ntb->ops->msg_read(ntb, pidx, midx);
 }
 
 /**
  * ntb_msg_write() - write data to the specified message register
  * @ntb:	NTB device context.
- * @midx:	Message register index
  * @pidx:	Port index of peer device a message being sent to
+ * @midx:	Message register index
  * @msg:	Data to send
  *
  * Send data to a specified peer device using the defined message register.
@@ -1495,13 +1493,13 @@ static inline int ntb_msg_read(struct ntb_dev *ntb, int midx, int *pidx,
  *
  * Return: Zero on success, otherwise a negative error number.
  */
-static inline int ntb_msg_write(struct ntb_dev *ntb, int midx, int pidx,
-				u32 msg)
+static inline int ntb_peer_msg_write(struct ntb_dev *ntb, int pidx, int midx,
+				     u32 msg)
 {
-	if (!ntb->ops->msg_write)
+	if (!ntb->ops->peer_msg_write)
 		return -EINVAL;
 
-	return ntb->ops->msg_write(ntb, midx, pidx, msg);
+	return ntb->ops->peer_msg_write(ntb, pidx, midx, msg);
 }
 
 #endif
@@ -1462,31 +1462,29 @@ static inline int ntb_msg_clear_mask(struct ntb_dev *ntb, u64 mask_bits)
 
 /**
- * ntb_msg_write() - write data to the specified message register
+ * ntb_peer_msg_write() - write data to the specified peer message register
  * @ntb:	NTB device context.
-- 
2.12.0

  reply	other threads:[~2017-12-06 14:32 UTC|newest]

Thread overview: 88+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2017-12-03 19:17 [PATCH v2 00/15] NTB: Add full multi-port API support to the test drivers Serge Semin
2017-12-03 19:17 ` [PATCH v2 01/15] NTB: Rename NTB messaging API methods Serge Semin
2017-12-05 16:49   ` Jon Mason
2017-12-05 17:31     ` Serge Semin
2017-12-05 18:07       ` Jon Mason
2017-12-05 20:54         ` Serge Semin
2017-12-05 21:48           ` Logan Gunthorpe
2017-12-05 19:11       ` Logan Gunthorpe
2017-12-03 19:17 ` [PATCH v2 02/15] NTB: Set dma mask and dma coherent mask to NTB devices Serge Semin
2017-12-05 16:51   ` Jon Mason
2017-12-05 17:21     ` Logan Gunthorpe
2017-12-05 17:48     ` Serge Semin
2017-12-03 19:17 ` [PATCH v2 03/15] NTB: Fix UB/bug in ntb_mw_get_align() Serge Semin
2017-12-05 16:52   ` Jon Mason
2017-12-05 17:01     ` Logan Gunthorpe
2017-12-05 17:08       ` Jon Mason
2017-12-05 17:56     ` Serge Semin
2017-12-05 18:08       ` Jon Mason
2017-12-05 20:57         ` Serge Semin
2017-12-03 19:17 ` [PATCH v2 04/15] NTB: ntb_pp: Add full multi-port NTB API support Serge Semin
2017-12-05 17:02   ` Jon Mason
2017-12-05 19:53     ` Serge Semin
2017-12-05 21:50       ` Logan Gunthorpe
2017-12-03 19:17 ` [PATCH v2 05/15] NTB: ntb_tool: " Serge Semin
2017-12-05 18:03   ` Jon Mason
2017-12-05 19:16     ` Logan Gunthorpe
2017-12-05 20:01     ` Serge Semin
2017-12-03 19:17 ` [PATCH v2 06/15] NTB: ntb_perf: " Serge Semin
2017-12-05 18:21   ` Jon Mason
2017-12-05 20:29     ` Serge Semin
2017-12-06  1:17   ` kbuild test robot
2017-12-03 19:17 ` [PATCH v2 07/15] NTB: ntb_test: Safely use paths with whitespace Serge Semin
2017-12-05 18:24   ` Jon Mason
2017-12-03 19:17 ` [PATCH v2 08/15] NTB: ntb_test: Add ntb_tool port tests Serge Semin
2017-12-03 19:17 ` [PATCH v2 09/15] NTB: ntb_test: Update ntb_tool link tests Serge Semin
2017-12-05 18:26   ` Jon Mason
2017-12-05 20:37     ` Serge Semin
2017-12-03 19:17 ` [PATCH v2 10/15] NTB: ntb_test: Update ntb_tool DB tests Serge Semin
2017-12-05 18:27   ` Jon Mason
2017-12-05 19:38     ` Logan Gunthorpe
2017-12-05 20:42     ` Serge Semin
2017-12-03 19:17 ` [PATCH v2 11/15] NTB: ntb_test: Update ntb_tool Scratchpad tests Serge Semin
2017-12-03 19:17 ` [PATCH v2 12/15] NTB: ntb_test: Add ntb_tool Message tests Serge Semin
2017-12-03 19:17 ` [PATCH v2 13/15] NTB: ntb_test: Update ntb_tool MW tests Serge Semin
2017-12-03 19:17 ` [PATCH v2 14/15] NTB: ntb_test: Update ntb_perf tests Serge Semin
2017-12-03 19:17 ` [PATCH v2 15/15] NTB: ntb_hw_idt: Set NTB_TOPO_SWITCH topology Serge Semin
2017-12-04  4:54 ` [PATCH v2 00/15] NTB: Add full multi-port API support to the test drivers Logan Gunthorpe
2017-12-04  6:12   ` Serge Semin
2017-12-04 20:10 ` Allen Hubbe
2017-12-05 15:54   ` Serge Semin
2017-12-05 16:57     ` Logan Gunthorpe
2017-12-05 22:39 ` [PATCH v3 " Serge Semin
2017-12-05 22:39   ` [PATCH v3 01/15] NTB: Rename NTB messaging API methods Serge Semin
2017-12-05 23:36     ` Logan Gunthorpe
2017-12-05 22:39   ` [PATCH v3 02/15] NTB: Set dma mask and dma coherent mask to NTB devices Serge Semin
2017-12-05 23:39     ` Logan Gunthorpe
2017-12-05 22:39   ` [PATCH v3 03/15] NTB: Fix UB/bug in ntb_mw_get_align() Serge Semin
2017-12-05 23:38     ` Logan Gunthorpe
2017-12-05 22:39   ` [PATCH v3 04/15] NTB: ntb_pp: Add full multi-port NTB API support Serge Semin
2017-12-05 22:39   ` [PATCH v3 05/15] NTB: ntb_tool: " Serge Semin
2017-12-05 22:39   ` [PATCH v3 06/15] NTB: ntb_perf: " Serge Semin
2017-12-05 22:39   ` [PATCH v3 07/15] NTB: ntb_test: Safely use paths with whitespace Serge Semin
2017-12-05 22:39   ` [PATCH v3 08/15] NTB: ntb_test: Add ntb_tool port tests Serge Semin
2017-12-05 22:39   ` [PATCH v3 09/15] NTB: ntb_test: Update ntb_tool link tests Serge Semin
2017-12-05 22:39   ` [PATCH v3 10/15] NTB: ntb_test: Update ntb_tool DB tests Serge Semin
2017-12-05 22:39   ` [PATCH v3 11/15] NTB: ntb_test: Update ntb_tool Scratchpad tests Serge Semin
2017-12-05 22:39   ` [PATCH v3 12/15] NTB: ntb_test: Add ntb_tool Message tests Serge Semin
2017-12-05 22:39   ` [PATCH v3 13/15] NTB: ntb_test: Update ntb_tool MW tests Serge Semin
2017-12-05 22:39   ` [PATCH v3 14/15] NTB: ntb_test: Update ntb_perf tests Serge Semin
2017-12-05 22:39   ` [PATCH v3 15/15] NTB: ntb_hw_idt: Set NTB_TOPO_SWITCH topology Serge Semin
2017-12-05 23:36   ` [PATCH v3 00/15] NTB: Add full multi-port API support to the test drivers Logan Gunthorpe
2017-12-06 14:31   ` [PATCH v4 " Serge Semin
2017-12-06 14:31     ` Serge Semin [this message]
2017-12-06 14:31     ` [PATCH v4 02/15] NTB: Set dma mask and dma coherent mask to NTB devices Serge Semin
2017-12-06 14:31     ` [PATCH v4 03/15] NTB: Fix UB/bug in ntb_mw_get_align() Serge Semin
2017-12-06 14:31     ` [PATCH v4 04/15] NTB: ntb_pp: Add full multi-port NTB API support Serge Semin
2017-12-06 14:31     ` [PATCH v4 05/15] NTB: ntb_tool: " Serge Semin
2017-12-06 14:31     ` [PATCH v4 06/15] NTB: ntb_perf: " Serge Semin
2017-12-06 14:31     ` [PATCH v4 07/15] NTB: ntb_test: Safely use paths with whitespace Serge Semin
2017-12-06 14:31     ` [PATCH v4 08/15] NTB: ntb_test: Add ntb_tool port tests Serge Semin
2017-12-06 14:32     ` [PATCH v4 09/15] NTB: ntb_test: Update ntb_tool link tests Serge Semin
2017-12-06 14:32     ` [PATCH v4 10/15] NTB: ntb_test: Update ntb_tool DB tests Serge Semin
2017-12-06 14:32     ` [PATCH v4 11/15] NTB: ntb_test: Update ntb_tool Scratchpad tests Serge Semin
2017-12-06 14:32     ` [PATCH v4 12/15] NTB: ntb_test: Add ntb_tool Message tests Serge Semin
2017-12-06 14:32     ` [PATCH v4 13/15] NTB: ntb_test: Update ntb_tool MW tests Serge Semin
2017-12-06 14:32     ` [PATCH v4 14/15] NTB: ntb_test: Update ntb_perf tests Serge Semin
2017-12-06 14:32     ` [PATCH v4 15/15] NTB: ntb_hw_idt: Set NTB_TOPO_SWITCH topology Serge Semin
2018-01-18 22:28     ` [PATCH v4 00/15] NTB: Add full multi-port API support to the test drivers Jon Mason

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20171206143206.14665-2-fancer.lancer@gmail.com \
    --to=fancer.lancer@gmail.com \
    --cc=Allen.Hubbe@emc.com \
    --cc=Sergey.Semin@t-platforms.ru \
    --cc=Shyam-sundar.S-k@amd.com \
    --cc=Xiangliang.Yu@amd.com \
    --cc=dave.jiang@intel.com \
    --cc=gary.hook@amd.com \
    --cc=jdmason@kudzu.us \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-ntb@googlegroups.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

Powered by JetHome